﻿using System.Collections.Generic;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Tsi1.BusinessLayer.Dtos;
using Tsi1.BusinessLayer.Helpers;
using Tsi1.BusinessLayer.Interfaces;

namespace Tsi1.Api.Controllers
{
    [Authorize(Roles = UserTypes.Professor)]
    [Route("api/[controller]")]
    [ApiController]
    public class SectionItemController : ControllerBase
    {
        private readonly ISectionItemService _sectionItemService;
        private readonly ISectionItemTypeService _sectionItemTypeService;

        public SectionItemController(ISectionItemService sectionItemService, ISectionItemTypeService sectionItemTypeService)
        {
            _sectionItemService = sectionItemService;
            _sectionItemTypeService = sectionItemTypeService;
        }

        [HttpPost("Create")]
        public async Task<IActionResult> Create(SectionItemCreateDto sectionItem)
        {
            var result = await _sectionItemService.Create(sectionItem);
            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok();
        }

        [HttpDelete("Delete/{sectionItemId}")]
        public async Task<IActionResult> Delete(int sectionItemId)
        {
            var result = await _sectionItemService.Delete(sectionItemId);
            if (result.HasError)
            {
                return NotFound(result.Message);
            }

            return Ok();
        }

        [HttpPost("ChangeOrder")]
        public async Task<IActionResult> ChangeOrder(List<OrderDto> orderDtos)
        {
            var result = await _sectionItemService.OrderSectionItems(orderDtos);
            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok();
        }

        [HttpGet("GetSectionItemTypes")]
        public async Task<IActionResult> GetSectionItemTypes()
        {
            var result = await _sectionItemTypeService.GetAll();
            return Ok(result.Data);
        }
    }
}
